==> offlinemot-1.0.1.tar.gz: offlinemot-1.0.1/offlinemot/tests/example_data.py <==
import numpy as np
import cv2

boxes =[[500,400,100,100],
        [0,0,100,50],
        [-10,0,100,100],
        [100,100,50,50]]


img_whs = [[400,400],
            [500,500],
            [200,200],
            [120,120]]

float_centers = [[550,450],
                [50,25],
                [40,50],
                [125,125]]
# test detection to box format

points = [(100,80),(10,8),(0,70)]

detections = [[(100,50),(200,150),0.9,-1],
                [(0,0),(100,150),0.9,2],
                [(7,50),(105,87),0.8,-1],
                [(7,50),(105,87),0.0,-1]]

results_0 = [[(200,130),(300,230),0.9,-1],
            [(100,80),(200,230),0.9,2],
            [(107,130),(205,167),0.8,-1]]

results_1 = [[(110,58),(210,158),0.9,-1],
            [(10,8),(110,158),0.9,2],
            [(17,58),(115,95),0.8,-1]]

results_2 = [[(100,120),(200,220),0.9,-1],
            [(0,70),(100,220),0.9,2],
            [(7,120),(105,157),0.8,-1]]

# boxes for detection
detect_boxes = [[100,50,100,100],
                [0,0,100,150],
                [7,50,98,37]]

# tracks and angels

track = [(0,0),
        (1,1),
        (2,2),
        (2,2),
        (3,3),
        (2,2),
        (3,3),
        (4,4),
        (5,5),
        (6,6),
        (6,6),
        (7,7)]

angels = [45,45,45,45,45,45,45,45,45,45,45,45]

trust_level = [[1,0,0],
                [0,1,0],
                [0,1,0],
                [0,1,0],
                [0,1,0],
                [0,1,0],
                [0,1,0],
                [0,0,0],
                [0,0,0],
                [0,1,0],
                [0,1,0],
                [0,1,0],
                [0,1,0],
                [0,1,0]]

# Matches
matches = []
d = 0
for q in range(3):
    for t in range(3):
        d += 1
        matches.append((cv2.DMatch(_queryIdx=q,_trainIdx=t+1,_distance=d),
                        cv2.DMatch(_queryIdx=q,_trainIdx=t,_distance=d+1)))

==> offlinemot-1.0.6.tar.gz: offlinemot-1.0.6/offlinemot/tests/example_data.py <==
import numpy as np
import cv2

boxes =[[500,400,100,100],
        [0,0,100,50],
        [-10,0,100,100],
        [100,100,50,50]]


img_whs = [[400,400],
            [500,500],
            [200,200],
            [120,120]]

float_centers = [[550,450],
                [50,25],
                [40,50],
                [125,125]]
# test detection to box format

points = [(100,80),(10,8),(0,70)]

detections = [[(100,50),(200,150),0.9,-1],
                [(0,0),(100,150),0.9,2],
                [(7,50),(105,87),0.8,-1],
                [(7,50),(105,87),0.0,-1]]

results_0 = [[(200,130),(300,230),0.9,-1],
            [(100,80),(200,230),0.9,2],
            [(107,130),(205,167),0.8,-1]]

results_1 = [[(110,58),(210,158),0.9,-1],
            [(10,8),(110,158),0.9,2],
            [(17,58),(115,95),0.8,-1]]

results_2 = [[(100,120),(200,220),0.9,-1],
            [(0,70),(100,220),0.9,2],
            [(7,120),(105,157),0.8,-1]]

# boxes for detection
detect_boxes = [(100,50,100,100),
                (0,0,100,150),
                (7,50,98,37)]

# tracks and angels

track = [(0,0),
        (1,1),
        (2,2),
        (2,2),
        (3,3),
        (2,2),
        (3,3),
        (4,4),
        (5,5),
        (6,6),
        (6,6),
        (7,7)]

angels = [45,45,45,45,45,45,45,45,45,45,45,45]

trust_level = [[1,0,0],
                [0,1,0],
                [0,1,0],
                [0,1,0],
                [0,1,0],
                [0,1,0],
                [0,1,0],
                [0,0,0],
                [0,0,0],
                [0,1,0],
                [0,1,0],
                [0,1,0],
                [0,1,0],
                [0,1,0]]

# Matches
matches = []
d = 0
for q in range(3):
    for t in range(3):
        d += 1
        matches.append((cv2.DMatch(_queryIdx=q,_trainIdx=t+1,_distance=d),
                        cv2.DMatch(_queryIdx=q,_trainIdx=t,_distance=d+1)))
